# Credits

## Development Lead

- Tissue Image Analytics Centre <TIA@warwick.ac.uk>
- Shan E Ahmed Raza \<@shaneahmed>
- John Pocock \<@John-P>
- Mark Eastwood \<@measty>
- Jiaqi Lv \<@Jiaqi-Lv>
- Mostafa Jahanifar \<@mostafajahanifar>
- Adam Shephard \<@adamshephard>
- Simon Graham \<@simongraham>
- Dang Vu \<@vqdang>
- David Epstein \<@DavidBAEpstein>
- Abdullah Alsalemi \<@Abdol>
- Ruqayya Awan \<@ruqayya>
- Dmitrii Blaginin \<@blaginin>
- Yijie Zhu \<@YijieZhu15>
- Srijay Deshpande \<@Srijay-lab>
- George Hadjigeorgiou \<@ghadjigeorghiou>
- Gozde Gunesli \<@gozdeg>
- Abishekraj Vinayagar Gnanasambandam \<@AbishekRajVG>
- Wenqi Lu \<@wenqi006>
- Saad Bashir \<@rajasaad>
- Behnaz Elhaminia \<@behnazelhaminia>

## Contributors

- Nasir Rajpoot \<@nmrajpoot>
- Fayyaz Minhas \<@foxtrotmike>
- George Batchkala \<@GeorgeBatch>
- Aleksandar Acic \<@aacic>
- Esha Nasir \<@eshasadia>
- Rob Jewsbury \<@R-J96>
- Mohsin Bilal \<@mbhahsmi>
- Musraf Basheer \<mbasheer04>
